@@ -7,25 +7,16 @@
 #include <X11/IntrinsicP.h>
 #include "Private.h"
 
-#ifndef X_NOT_POSIX
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>	/* for sysconf(), and getpagesize() */
 #endif
 
 #if defined(linux)
 /* kernel header doesn't work with -ansi */
 /* #include <asm/page.h> *//* for PAGE_SIZE */
-#define HAS_GETPAGESIZE
 #define HAS_SC_PAGESIZE	/* _SC_PAGESIZE may be an enum for Linux */
 #endif
 
-#if defined(CSRG_BASED)
-#define HAS_GETPAGESIZE
-#endif
-
-#if defined(sun)
-#define HAS_GETPAGESIZE
-#endif
-
 int
 _XawGetPageSize(void)
 {
@@ -45,7 +36,7 @@ _XawGetPageSize(void)
 	pagesize = sysconf(_SC_PAGE_SIZE);
 #endif
 
-#ifdef HAS_GETPAGESIZE
+#ifdef HAVE_GETPAGESIZE
     if (pagesize == -1)
 	pagesize = getpagesize();
 #endif
